import 'package:flutter/material.dart';
import 'package:sigma_ui/sigma_ui.dart';

const SUI_APP_BAR_HEIGHT = 50.0;

class SuiAppBar extends StatelessWidget
    with SigmaUiMixin
    implements PreferredSizeWidget {
  const SuiAppBar({
    Key? key,
    required this.title,
    this.action,
    this.backgroundColor,
    this.showTitle = true,
    this.transparent = false,
    this.onTapBack,
    this.leading,
    this.bottom,
    this.height = SUI_APP_BAR_HEIGHT,
  }) : super(key: key);

  final String title;
  final Widget? action;
  final Widget? leading;
  final Color? backgroundColor;
  final bool showTitle;
  final bool transparent;
  final Function()? onTapBack;
  final PreferredSizeWidget? bottom;
  final double? height;

  @override
  Widget build(BuildContext context) {
    final isLight = SigmaUiThemeHelper.isLight(context);
    final primaryColor = Theme.of(context).primaryColor;

    return AppBar(
      backgroundColor: backgroundColor ??
          (!transparent
              ? (isLight
                  ? theme.colors.white
                  : Theme.of(context).appBarTheme.backgroundColor)
              : Colors.transparent),
      leading: leading ??
          (Navigator.of(context).canPop()
              ? IconButton(
                  icon: Icon(Icons.chevron_left_rounded),
                  onPressed: onTapBack ?? () => Navigator.of(context).pop(),
                  // color: theme.colors.primary,
                )
              : null),
      title: showTitle
          ? SuiText.bodyBold(
              title,
              style: theme.textStyles.bodyBold.copyWith(
                fontSize: 14,
                color: isLight ? primaryColor : null,
              ),
            )
          : SizedBox.shrink(),
      centerTitle: true,
      bottom: bottom,
      iconTheme: IconThemeData(
        color: isLight ? primaryColor : null,
      ),
      actionsIconTheme: IconThemeData(
        color: isLight ? primaryColor : null,
      ),
      // backgroundColor: theme.colors.white,
      // actionsIconTheme: IconThemeData(color: theme.colors.black),
      elevation: 0,
      actions: [
        if (action != null) action!,
      ],
    );
  }

  @override
  Size get preferredSize => Size.fromHeight(height!);
}
