import 'package:flutter/material.dart';
import 'package:sigma_ui/sigma_ui.dart';

class SuiBottomNavigationBar extends StatelessWidget with SigmaUiMixin {
  const SuiBottomNavigationBar({
    Key? key,
    required this.controller,
    required this.tabs,
  }) : super(key: key);

  final TabController controller;
  final List<SuiBottomNavigationBarItem> tabs;

  @override
  Widget build(BuildContext context) {
    final primaryColor = Theme.of(context).primaryColor;
    final isLight = SigmaUiThemeHelper.isLight(context);

    return Container(
      height: 60,
      padding: theme.padding.all5,
      decoration: BoxDecoration(
        color: isLight
            ? theme.colors.white
            : Theme.of(context).bottomNavigationBarTheme.backgroundColor,
        boxShadow: [
          BoxShadow(
            offset: Offset(0, 1),
            color: Colors.black.withOpacity(0.1),
            spreadRadius: 2.0,
            blurRadius: 5.0,
          ),
        ],
      ),
      child: TabBar(
        controller: controller,
        indicatorSize: TabBarIndicatorSize.label,
        indicatorColor: primaryColor,
        labelColor: primaryColor,
        unselectedLabelColor: SigmaUiThemeHelper.isLight(context)
            ? theme.colors.black.withOpacity(0.4)
            : Colors.grey,
        tabs: tabs,
      ),
    );
  }
}
