import 'package:flutter/material.dart';
import 'package:sigma_ui/sigma_ui.dart';

enum SuiButtonType {
  basic,
  text,
}

class SuiButton extends StatelessWidget with SigmaUiMixin {
  const SuiButton({
    Key? key,
    required this.label,
    required this.onPressed,
    this.busy = false,
    this.disabled = false,
    this.textColor = kcWhite,
    this.color = kcPrimary,
    this.borderRadius,
  })  : variant = SuiButtonType.basic,
        super(key: key);

  const SuiButton.text({
    Key? key,
    required this.label,
    required this.onPressed,
    this.busy = false,
    this.disabled = false,
    this.textColor,
    this.borderRadius,
  })  : color = null,
        variant = SuiButtonType.text,
        super(key: key);

  final String label;
  final bool? busy;
  final bool? disabled;
  final VoidCallback? onPressed;
  final Color? color;
  final Color? textColor;
  final BorderRadiusGeometry? borderRadius;
  final SuiButtonType variant;

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
      onPressed: disabled! ? null : onPressed,
      // TODO: Create a disabled color variable
      disabledColor: Colors.grey[500],
      textColor: textColor ?? Theme.of(context).textTheme.bodyText1!.color,
      shape: RoundedRectangleBorder(
        borderRadius: borderRadius ?? theme.borderRadius.huge,
      ),
      child: busy!
          ? SuiSpinner(
              color: variant == SuiButtonType.text
                  ? Theme.of(context).primaryColor
                  : kcWhite,
            )
          : Center(
              child: Text(
                label,
                style: TextStyle(
                  fontWeight: variant == SuiButtonType.basic
                      ? FontWeight.bold
                      : FontWeight.normal,
                  fontSize: 16,
                  color: textColor ?? Theme.of(context).primaryColor,
                ),
              ),
            ),
      color: variant == SuiButtonType.basic
          ? Theme.of(context).primaryColor
          : null,
      height: 50,
      elevation: 0,
      focusElevation: 0,
      hoverElevation: 0,
      disabledElevation: 0,
      highlightElevation: 0,
    );
  }
}
