import 'package:flutter/material.dart';
import 'package:sigma_ui/sigma_ui.dart';
import 'package:stacked_services/stacked_services.dart';

enum SuiDialogType {
  basic,
  success,
  error,
  info,
  warning,
}

class SuiDialog extends StatelessWidget {
  const SuiDialog({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.basic,
  }) : super(key: key);

  const SuiDialog.basic({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.basic,
  }) : super(key: key);

  const SuiDialog.success({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.success,
  }) : super(key: key);

  const SuiDialog.error({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.error,
  }) : super(key: key);

  const SuiDialog.info({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.info,
  }) : super(key: key);

  const SuiDialog.warning({
    Key? key,
    required this.request,
    required this.completer,
    this.variant = SuiDialogType.warning,
  }) : super(key: key);

  final SuiDialogType variant;
  final DialogRequest request;
  final Function(DialogResponse) completer;

  SigmaUi get theme => SigmaUi();
  // BoxConstraints get boxConstraints =>

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      shape: RoundedRectangleBorder(
        borderRadius: theme.borderRadius.huge,
      ),
      child: Container(
        constraints: BoxConstraints(
          minHeight: 150,
          maxHeight: 200,
          minWidth: 300,
        ),
        padding: theme.padding.all10,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            theme.verticalSpacing.large,
            SuiText.headline(request.title ?? 'Title'),
            theme.verticalSpacing.large,
            SuiText.body(
              request.description ?? 'Description',
              textAlign: TextAlign.justify,
              overflow: TextOverflow.ellipsis,
              maxLines: 7,
            ),
            Spacer(),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                Expanded(
                  child: SuiButton.text(
                    label: 'Cancel',
                    onPressed: () =>
                        completer(DialogResponse(confirmed: false)),
                    textColor: theme.colors.primary,
                    borderRadius: theme.borderRadius.huge,
                  ),
                ),
                Expanded(
                  child: SuiButton.text(
                    label: 'Confirm',
                    onPressed: () => completer(DialogResponse(confirmed: true)),
                    textColor: theme.colors.primary,
                    borderRadius: theme.borderRadius.huge,
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
