import 'package:flutter/material.dart';
import 'package:flutter_form_builder/flutter_form_builder.dart';
import 'package:sigma_ui/sigma_ui.dart';

enum SuiDropdownFieldLabelType {
  basic,
  stacked,
  floating,
}

class SuiDropdownField extends StatelessWidget with SigmaUiMixin {
  const SuiDropdownField({
    Key? key,
    required this.name,
    required this.items,
    this.focusNode,
    this.label,
    this.help,
    this.error,
    this.labelType = SuiDropdownFieldLabelType.basic,
    this.suffixIcon,
    this.onChanged,
    this.onSaved,
    this.onTap,
    this.backgroundColor,
    this.validator,
    this.initialValue,
  }) : super(key: key);

  final String name;
  final String? label;
  final String? help;
  final String? error;
  final SuiDropdownFieldLabelType? labelType;
  final FocusNode? focusNode;
  final Color? backgroundColor;
  final Widget? suffixIcon;
  final ValueChanged<String?>? onChanged;
  final FormFieldSetter<String>? onSaved;
  final GestureTapCallback? onTap;
  final FormFieldValidator<String>? validator;
  final List<String> items;
  final String? initialValue;

  List<Widget> get labelText {
    if (labelType == SuiDropdownFieldLabelType.basic) {
      return [SizedBox.shrink()];
    }

    if (label == null) {
      return [SizedBox.shrink()];
    }

    return [
      Row(children: [SuiText.body(label!)]),
      theme.verticalSpacing.normal,
    ];
  }

  List<Widget> get captionText {
    if (error != null) {
      return [
        theme.verticalSpacing.normal,
        Align(
          alignment: Alignment.topLeft,
          child: Wrap(
            alignment: WrapAlignment.start,
            crossAxisAlignment: WrapCrossAlignment.start,
            children: [
              SuiText.caption(
                error!,
                style: theme.textStyles.caption.copyWith(
                  color: theme.colors.error,
                ),
              )
            ],
          ),
        ),
      ];
    }

    if (help != null) {
      return [
        theme.verticalSpacing.normal,
        Align(
          alignment: Alignment.topLeft,
          child: Wrap(
            alignment: WrapAlignment.start,
            crossAxisAlignment: WrapCrossAlignment.start,
            children: [
              SuiText.caption(
                help!,
                // style: theme.textStyles.caption.copyWith(
                //   fontSize: 14,
                // ),
              ),
            ],
          ),
        ),
      ];
    }

    return [SizedBox.shrink()];
  }

  Color get fillColor {
    if (error == null) {
      return theme.colors.veryLightGrey;
    }

    return theme.colors.error.withOpacity(0.8);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ...labelText,
        Stack(
          children: [
            Container(
              padding: theme.padding.horizontalSymmetric15,
              height: 50,
              decoration: BoxDecoration(
                color: backgroundColor ?? SigmaUiThemeHelper.isLight(context)
                    ? fillColor
                    : Theme.of(context).canvasColor,
                borderRadius: theme.borderRadius.huge,
              ),
            ),
            Container(
              padding: theme.padding.horizontalSymmetric15,
              child: FormBuilderDropdown(
                name: name,
                focusNode: focusNode,
                decoration: InputDecoration(
                  hintText: label,
                  border: InputBorder.none,
                  suffixIcon: suffixIcon,
                ),
                allowClear: true,
                onChanged: onChanged,
                onSaved: onSaved,
                onTap: onTap,
                validator: validator,
                initialValue: initialValue,
                items: items
                    .map((item) => DropdownMenuItem(
                          value: item,
                          child: Text(item),
                        ))
                    .toList(),
              ),
            ),
          ],
        ),
        ...captionText,
      ],
    );
  }
}
