import 'package:flutter/material.dart';
import 'package:flutter_form_builder/flutter_form_builder.dart';
import 'package:sigma_ui/sigma_ui.dart';

enum SuiTextFieldLabelType {
  basic,
  stacked,
  floating,
}

class SuiTextField extends StatelessWidget with SigmaUiMixin {
  const SuiTextField({
    Key? key,
    required this.name,
    this.controller,
    this.focusNode,
    this.label,
    this.help,
    this.error,
    this.labelType = SuiTextFieldLabelType.basic,
    this.suffixIcon,
    this.onChanged,
    this.onEditingComplete,
    this.onSubmitted,
    this.onSaved,
    this.onTap,
    this.readOnly = false,
    this.obscureText = false,
    this.autocorrect = false,
    this.keyboardType,
    this.backgroundColor,
    this.validator,
    this.initialValue,
    this.maxLines = 1,
    this.maxLength,
    this.height,
  }) : super(key: key);

  final String name;
  final String? label;
  final String? help;
  final String? error;
  final SuiTextFieldLabelType? labelType;
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final Color? backgroundColor;
  final Widget? suffixIcon;
  final ValueChanged<String?>? onChanged;
  final VoidCallback? onEditingComplete;
  final ValueChanged<String>? onSubmitted;
  final FormFieldSetter<String>? onSaved;
  final GestureTapCallback? onTap;
  final bool readOnly;
  final bool obscureText;
  final bool autocorrect;
  final TextInputType? keyboardType;
  final FormFieldValidator<String>? validator;
  final String? initialValue;
  final int maxLines;
  final int? maxLength;
  final double? height;

  List<Widget> get labelText {
    if (labelType == SuiTextFieldLabelType.basic) {
      return [SizedBox.shrink()];
    }

    if (label == null) {
      return [SizedBox.shrink()];
    }

    return [
      Row(children: [SuiText.body(label!)]),
      theme.verticalSpacing.normal,
    ];
  }

  List<Widget> get captionText {
    if (error != null) {
      return [
        theme.verticalSpacing.normal,
        Align(
          alignment: Alignment.topLeft,
          child: Wrap(
            alignment: WrapAlignment.start,
            crossAxisAlignment: WrapCrossAlignment.start,
            children: [
              SuiText.caption(
                error!,
                style: theme.textStyles.caption.copyWith(
                  color: theme.colors.error,
                ),
              )
            ],
          ),
        ),
      ];
    }

    if (help != null) {
      return [
        theme.verticalSpacing.normal,
        Align(
          alignment: Alignment.topLeft,
          child: Wrap(
            alignment: WrapAlignment.start,
            crossAxisAlignment: WrapCrossAlignment.start,
            children: [
              SuiText.caption(
                help!,
                // style: theme.textStyles.caption.copyWith(
                //   fontSize: 14,
                // ),
              ),
            ],
          ),
        ),
      ];
    }

    return [SizedBox.shrink()];
  }

  Color get fillColor {
    if (error == null) {
      return theme.colors.veryLightGrey;
    }

    return theme.colors.error.withOpacity(0.8);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ...labelText,
        Stack(
          children: [
            Container(
              padding: theme.padding.horizontalSymmetric15,
              constraints: BoxConstraints(minHeight: height ?? 50),
              decoration: BoxDecoration(
                color: backgroundColor ?? SigmaUiThemeHelper.isLight(context)
                    ? fillColor
                    : Theme.of(context).canvasColor,
                borderRadius: theme.borderRadius.huge,
              ),
            ),
            Container(
              padding: theme.padding.horizontalSymmetric15,
              child: FormBuilderTextField(
                name: name,
                controller: controller,
                focusNode: focusNode,
                decoration: InputDecoration(
                  hintText: label,
                  border: InputBorder.none,
                  suffixIcon: suffixIcon,
                ),
                maxLines: maxLines,
                maxLength: maxLength,
                initialValue: initialValue,
                keyboardType: keyboardType,
                onChanged: onChanged,
                onEditingComplete: onEditingComplete,
                onSubmitted: onSubmitted,
                onSaved: onSaved,
                onTap: onTap,
                readOnly: readOnly,
                obscureText: obscureText,
                autocorrect: autocorrect,
                validator: validator,
              ),
            ),
          ],
        ),
        ...captionText,
      ],
    );
  }
}
